@@ -1,8 +1,7 @@
-from IPython.core.magic import cell_magic, line_magic, Magics, magics_class
+from IPython.core.magic import Magics, cell_magic, line_magic, magics_class
 
 from jupyter_spaces.space import SpaceRegister
 
-
 space_register = SpaceRegister()
 
 
@@ -22,7 +21,7 @@ class SpaceMagic(Magics):
         Examples:
             >>> %%space space_name
             ... alpha = 0.50
-            ... print(alpha)
+            ... alpha
         """
         space = space_register.get_space(name=line, outer_space=self.shell.user_ns)
         space.execute(source=cell)
